Structs
- Chunked
MutIter - An iterator that chunks an
RangeSetinto fixed-size blocks. - Frozen
Range Set - An immutable collection of non-overlapping, sorted ranges.
- Range
- An inclusive range defined by start and last offsets.
- Range
Set - A set of non-overlapping inclusive ranges.
Enums
- Error
- Error types that can occur when working with range sets.